from pathlib import Path
from typing import Any

import stacrs


def test_migrate(item: dict[str, Any]) -> None:
    item = stacrs.migrate(item, version="1.1.0")
    assert item["stac_version"] == "1.1.0"


def test_migrate_href(spec_examples: Path) -> None:
    item = stacrs.migrate_href(
        str(spec_examples / "v1.0.0" / "simple-item.json"), version="1.1.0"
    )
    assert item["stac_version"] == "1.1.0"



import json
from pathlib import Path
from typing import Any

import pytest


@pytest.fixture
def root() -> Path:
    return Path(__file__).parents[1]


@pytest.fixture
def spec_examples(root: Path) -> Path:
    return root / "spec-examples"


@pytest.fixture
def examples(root: Path) -> Path:
    return root / "spec-examples" / "v1.1.0"


@pytest.fixture
def data(root: Path) -> Path:
    return root / "data"


@pytest.fixture
def item(examples: Path) -> dict[str, Any]:
    with open(examples / "simple-item.json") as f:
        return json.load(f)



import pytest
import stacrs
from geopandas import GeoDataFrame
from stacrs import DuckdbClient


@pytest.fixture
def client() -> DuckdbClient:
    return DuckdbClient()


def test_search(client: DuckdbClient) -> None:
    item_collection = client.search("data/extended-item.parquet")
    assert len(item_collection["features"]) == 1


def test_search_offset(client: DuckdbClient) -> None:
    item_collection = client.search(
        "data/100-sentinel-2-items.parquet", offset=0, limit=1
    )
    assert (
        item_collection["features"][0]["id"]
        == "S2B_MSIL2A_20241203T174629_R098_T13TDE_20241203T211406"
    )

    item_collection = client.search(
        "data/100-sentinel-2-items.parquet", offset=1, limit=1
    )
    assert (
        item_collection["features"][0]["id"]
        == "S2A_MSIL2A_20241201T175721_R141_T13TDE_20241201T213150"
    )


def test_get_collections(client: DuckdbClient) -> None:
    collections = client.get_collections("data/100-sentinel-2-items.parquet")
    assert len(collections) == 1


def test_init_with_config() -> None:
    DuckdbClient(use_s3_credential_chain=True, use_hive_partitioning=True)


def test_search_to_arrow(client: DuckdbClient) -> None:
    pytest.importorskip("arro3.core")
    table = client.search_to_arrow("data/100-sentinel-2-items.parquet")
    data_frame = GeoDataFrame.from_arrow(table)
    assert len(data_frame) == 100
    data_frame_table = data_frame.to_arrow()
    item_collection = stacrs.from_arrow(data_frame_table)
    assert len(item_collection["features"]) == 100



from pathlib import Path

import stacrs
from pystac import Item


async def test_read(examples: Path) -> None:
    item = Item.from_dict(await stacrs.read(str(examples / "simple-item.json")))
    item.validate()



from typing import Any

import pytest
import stacrs
from geopandas import GeoDataFrame

pytest.importorskip("arro3.core")


def test_to_arrow(item: dict[str, Any]) -> None:
    table = stacrs.to_arrow([item])
    data_frame = GeoDataFrame.from_arrow(table)
    assert len(data_frame) == 1



import json
from pathlib import Path

import pyarrow.parquet
import stac_geoparquet.arrow
import stacrs


async def test_search() -> None:
    items = await stacrs.search(
        "https://landsatlook.usgs.gov/stac-server",
        collections="landsat-c2l2-sr",
        intersects={"type": "Point", "coordinates": [-105.119, 40.173]},
        sortby="-properties.datetime",
        max_items=1,
    )
    assert len(items) == 1


async def test_search_to(tmp_path: Path) -> None:
    await stacrs.search_to(
        str(tmp_path / "out.json"),
        "https://landsatlook.usgs.gov/stac-server",
        collections="landsat-c2l2-sr",
        intersects={"type": "Point", "coordinates": [-105.119, 40.173]},
        sortby="-properties.datetime",
        max_items=1,
    )
    with open(tmp_path / "out.json") as f:
        data = json.load(f)
    assert len(data["features"]) == 1


async def test_search_to_geoparquet(tmp_path: Path) -> None:
    count = await stacrs.search_to(
        str(tmp_path / "out.parquet"),
        "https://landsatlook.usgs.gov/stac-server",
        collections="landsat-c2l2-sr",
        intersects={"type": "Point", "coordinates": [-105.119, 40.173]},
        sortby="-properties.datetime",
        max_items=1,
    )
    assert count == 1
    table = pyarrow.parquet.read_table(tmp_path / "out.parquet")
    items = list(stac_geoparquet.arrow.stac_table_to_items(table))
    assert len(items) == 1


async def test_search_geoparquet(data: Path) -> None:
    items = await stacrs.search(str(data / "extended-item.parquet"))
    assert len(items) == 1



import stacrs


def test_version() -> None:
    assert stacrs.version() is not None
    assert stacrs.version("stac") is not None
    assert stacrs.version("stac-api") is not None
    assert stacrs.version("stac-duckdb") is not None
